
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.*;
import java.nio.charset.StandardCharsets;
import java.util.Base64;

/**
 * 
 * @author librabin
 *
 */
public class ClientProxyBasicHttp {

	public static void main(String args[]) throws Exception {
		// 目标地址
		String targetUrl = "http://xxxx";
		// 代理服务器
		String proxyHost = "xxx.xxx.xxx.xxx";
		int proxyPort = 10086;
		// 代理验证
		String proxyUser = "用户名";
		String proxyPwd = "密码";

		try {
			// 创建代理服务器
			InetSocketAddress addr = new InetSocketAddress(proxyHost, proxyPort);
			Proxy proxy = new Proxy(Proxy.Type.HTTP, addr);
			// 访问目标网页
			URL url = new URL(targetUrl);

			HttpURLConnection conn = (HttpURLConnection) url.openConnection(proxy);

			Authenticator.setDefault(new Authenticator() {
				protected PasswordAuthentication getPasswordAuthentication() {
					return new PasswordAuthentication(proxyUser, proxyPwd.toCharArray());
				}
			});

			String auth = proxyUser + ":" + proxyPwd;
			//用户名：密码  格式然后base64转码成ascii格式的（请求头不能使用非ascii的编码）
			String basic = Base64.getEncoder().encodeToString(auth.getBytes());
			basic = basic.replace("\n", "").replace("\r", "");
			conn.setRequestProperty("Proxy-Authorization", "Basic " + basic);

			conn.connect();
			int code = conn.getResponseCode();
			System.out.println("http code:" + code);
			// 读取返回数据
			InputStream in = conn.getInputStream();
			// 将返回数据转换成字符串
			System.out.println(IO2String(in));

		} catch (Exception e) {
			e.printStackTrace();
		}
	}


	/**
	 * 将输入流转换成字符串
	 * 
	 * @param inStream
	 * @return
	 * @throws IOException
	 */
	public static String IO2String(InputStream inStream) throws IOException {
		ByteArrayOutputStream result = new ByteArrayOutputStream();
		byte[] buffer = new byte[1024];
		int len;
		while ((len = inStream.read(buffer)) != -1) {
			result.write(buffer, 0, len);
		}
		String str = result.toString(StandardCharsets.UTF_8.name());
		return str;
	}
	
	static class ProxyAuthenticator extends Authenticator {
		private String authUser, authPwd;
		
		public ProxyAuthenticator(String authUser, String authPwd) {
			this.authUser = authUser;
			this.authPwd = authPwd;
		}
		
        public PasswordAuthentication getPasswordAuthentication() {
            return (new PasswordAuthentication(authUser, authPwd.toCharArray()));
        }
    }
}
